@@ -1,4 +1,4 @@
-from pyproject import add
+from my_python_api import add
 
 def test_add():
     assert add(1, 2) == 3
